# 2025.7.0

**Released on July 10th, 2025**

[Documentation for this release](https://cotainr.readthedocs.org/en/2025.7.0/)

A major release focused on streamlining of the development and CI/CD setup, updating documentation, multiple bugfixes and bumping versions of python, apptainer & singularity.

## New features

- Cotainr CI/CD pipeline has moved to a containerized dev environment with a single sourced test matrix and streamlined testing setup which includes: automatic container building, using containers in the CI/CD pipeline and using containers for testing on local dev machines, [PR#123](https://github.com/DeiC-HPC/cotainr/pull/123)[PR#130](https://github.com/DeiC-HPC/cotainr/pull/130)[PR#142](https://github.com/DeiC-HPC/cotainr/pull/142)[PR#138](https://github.com/DeiC-HPC/cotainr/pull/138)[PR#146](https://github.com/DeiC-HPC/cotainr/pull/146)[PR#150](https://github.com/DeiC-HPC/cotainr/pull/150)[PR#152](https://github.com/DeiC-HPC/cotainr/pull/152)[PR#155](http://github.com/DeiC-HPC/cotainr/pull/155)[PR#139](https://github.com/DeiC-HPC/cotainr/pull/139)[PR#153](https://github.com/DeiC-HPC/cotainr/pull/153)[PR#163](https://github.com/DeiC-HPC/cotainr/pull/163)
- Cotainr uses a dynamic versioning scheme using the hatch-vcs single-sourced version number setup based on Git tags, [PR#132](https://github.com/DeiC-HPC/cotainr/pull/132)

## Bug fixes

- Added a fifth verbosity level to cotainr. This allows for more debug information from singularity/apptainer while allowing for a more fine grained selection of conda debug/tracing information, [PR#157](https://github.com/DeiC-HPC/cotainr/pull/157).
- Consistently require a yes/no answer throughout cotainr when prompting the user for confirmation, [PR#64](https://github.com/DeiC-HPC/cotainr/pull/64).
- Move conda installations added by cotainr to a cotainr specific path (/opt/cotainr/conda) rather than the standard conda path (/opt/conda) to avoid interfering with existing conda installations, [PR#66](https://github.com/DeiC-HPC/cotainr/pull/66).
- More robust resetting of the logging system between tests of cotainr to make sure the tests start from a clean slate, [PR#154](https://github.com/DeiC-HPC/cotainr/pull/154).

## Maintenance updates

- Major documentation overhaul to reflect the latest changes and to document our procedures more thoroughly, [PR#159](https://github.com/DeiC-HPC/cotainr/pull/159).
- Add Python 3.13 support, [PR#164](https://github.com/DeiC-HPC/cotainr/pull/164).
- Added and tested latest versions of apptainer (v1.4.1) and singularity (v4.3.2) in the CI/CD pipelines, [PR#162](https://github.com/DeiC-HPC/cotainr/pull/162).
